@@ -328,6 +328,11 @@ OtamaObject_create_table(OtamaObject *self)
 {
     otama_status_t ret;
 
+    if (!self->otama) {
+        PyErr_SetString(PyExc_OtamaError, "not initialize/config error");
+        return NULL;
+    }
+
     ret = otama_create_table(self->otama);
     if (ret != OTAMA_STATUS_OK) {
         otamapy_raise(ret);
@@ -341,6 +346,11 @@ OtamaObject_drop_table(OtamaObject *self)
 {
     otama_status_t ret;
 
+    if (!self->otama) {
+        PyErr_SetString(PyExc_OtamaError, "not initialize/config error");
+        return NULL;
+    }
+
     ret = otama_drop_table(self->otama);
     if (ret != OTAMA_STATUS_OK) {
         otamapy_raise(ret);
@@ -366,6 +376,11 @@ OtamaObject_search(OtamaObject *self, PyObject *args)
         return NULL;
     }
 
+    if (!self->otama) {
+        PyErr_SetString(PyExc_OtamaError, "not initialize/config error");
+        return NULL;
+    }
+
 	pool = otama_variant_pool_alloc();
 	var = otama_variant_new(pool);
     pyobj2variant(data, var);
