@@ -9,4 +9,5 @@ class TestOtama(unittest.TestCase):
         self.db = Otama()
 
     def test_open(self):
-        self.assertEqual(None, None)
+        o = Otama()
+        self.assertEqual(type(o), Otama)
